==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments.md <==
# AwsSystemsManagerDocuments


```text
aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments
```

```text
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments')
```



| Illustration | AwsSystemsManagerDocuments | AwsSystemsManagerDocumentsCard | AwsSystemsManagerDocumentsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments.png) | ![illustration for AwsSystemsManagerDocuments](../../../aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments.Local.png) | ![illustration for AwsSystemsManagerDocumentsCard](../../../aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocumentsCard.Local.png) | ![illustration for AwsSystemsManagerDocumentsGroup](../../../aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocumentsGroup.Local.png) |




## AwsSystemsManagerDocuments

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerDocuments
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments')

' renders the element
AwsSystemsManagerDocuments('AwsSystemsManagerDocuments', 'Aws Systems Manager Documents', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerDocuments
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments')

' renders the element
AwsSystemsManagerDocuments('AwsSystemsManagerDocuments', 'Aws Systems Manager Documents', 'an optional tech label')
@enduml
```

## AwsSystemsManagerDocumentsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerDocumentsCard
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments')

' renders the element
AwsSystemsManagerDocumentsCard('AwsSystemsManagerDocumentsCard', 'Aws Systems Manager Documents Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerDocumentsCard
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments')

' renders the element
AwsSystemsManagerDocumentsCard('AwsSystemsManagerDocumentsCard', 'Aws Systems Manager Documents Card', 'an optional description')
@enduml
```

## AwsSystemsManagerDocumentsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerDocumentsGroup
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments')

' renders the element
AwsSystemsManagerDocumentsGroup('AwsSystemsManagerDocumentsGroup', 'Aws Systems Manager Documents Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerDocumentsGroup
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments')

' renders the element
AwsSystemsManagerDocumentsGroup('AwsSystemsManagerDocumentsGroup', 'Aws Systems Manager Documents Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments.md <==
# AwsSystemsManagerDocuments


```text
aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments
```

```text
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments')
```



| Illustration | AwsSystemsManagerDocuments | AwsSystemsManagerDocumentsCard | AwsSystemsManagerDocumentsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments.png) | ![illustration for AwsSystemsManagerDocuments](../../../aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments.Local.png) | ![illustration for AwsSystemsManagerDocumentsCard](../../../aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocumentsCard.Local.png) | ![illustration for AwsSystemsManagerDocumentsGroup](../../../aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocumentsGroup.Local.png) |




## AwsSystemsManagerDocuments

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerDocuments
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments')

' renders the element
AwsSystemsManagerDocuments('AwsSystemsManagerDocuments', 'Aws Systems Manager Documents', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerDocuments
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments')

' renders the element
AwsSystemsManagerDocuments('AwsSystemsManagerDocuments', 'Aws Systems Manager Documents', 'an optional tech label')
@enduml
```

## AwsSystemsManagerDocumentsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerDocumentsCard
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments')

' renders the element
AwsSystemsManagerDocumentsCard('AwsSystemsManagerDocumentsCard', 'Aws Systems Manager Documents Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerDocumentsCard
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments')

' renders the element
AwsSystemsManagerDocumentsCard('AwsSystemsManagerDocumentsCard', 'Aws Systems Manager Documents Card', 'an optional description')
@enduml
```

## AwsSystemsManagerDocumentsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerDocumentsGroup
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments')

' renders the element
AwsSystemsManagerDocumentsGroup('AwsSystemsManagerDocumentsGroup', 'Aws Systems Manager Documents Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerDocumentsGroup
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerDocuments')

' renders the element
AwsSystemsManagerDocumentsGroup('AwsSystemsManagerDocumentsGroup', 'Aws Systems Manager Documents Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
